@@ -25,9 +25,16 @@
 #include "gstmpegdemux.h"
 #include "gstmpegtsdemux.h"
 
+GST_DEBUG_CATEGORY_EXTERN (gstflupesfilter_debug);
+GST_DEBUG_CATEGORY_EXTERN (gstflusectionfilter_debug);
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
+  GST_DEBUG_CATEGORY_INIT (gstflupesfilter_debug, "flupesfilter", 0,
+      "MPEG-TS/PS PES filter output");
+  GST_DEBUG_CATEGORY_INIT (gstflusectionfilter_debug, "flusectionfilter", 0,
+      "MPEG-TS Section filter output");
+
   if (!gst_flups_demux_plugin_init (plugin))
     return FALSE;
   if (!gst_fluts_demux_plugin_init (plugin))
@@ -42,4 +49,3 @@ GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     "MPEG demuxers",
     plugin_init, VERSION,
     GST_LICENSE_UNKNOWN, "flumpegdemux", "http://www.fluendo.com/");
-
